@@ -9,7 +9,8 @@
 # AllGenerics .... the generics defined in DESeq2
 # results ........ results() function and helpers
 # plots .......... all plotting functions
-# helper ......... lfcShrink, collapseReplicates, fpkm, fpm, DESeqParallel
+# lfcShrink ...... log2 fold change shrinkage
+# helper ......... unmix, collapseReplicates, fpkm, fpm, DESeqParallel
 # expanded ....... helpers for dealing with expanded model matrices
 # wrappers ....... the R wrappers for the C++ functions (mine)
 # RcppExports .... the R wrappers for the C++ functions (auto)
@@ -58,11 +59,11 @@
 #'
 #' DESeq2 reference:
 #' 
-#' Michael I Love, Wolfgang Huber, Simon Anders: Moderated estimation of fold change and dispersion for RNA-seq data with DESeq2. Genome Biology 2014, 15:550. \url{http://dx.doi.org/10.1186/s13059-014-0550-8}
+#' Love, M.I., Huber, W., Anders, S. (2014) Moderated estimation of fold change and dispersion for RNA-seq data with DESeq2. Genome Biology, 15:550. \url{http://dx.doi.org/10.1186/s13059-014-0550-8}
 #'
 #' DESeq reference:
 #' 
-#' Simon Anders, Wolfgang Huber: Differential expression analysis for sequence count data. Genome Biology 2010, 11:106. \url{http://dx.doi.org/10.1186/gb-2010-11-10-r106}
+#' Simon Anders, Wolfgang Huber (2010) Differential expression analysis for sequence count data. Genome Biology, 11:106. \url{http://dx.doi.org/10.1186/gb-2010-11-10-r106}
 #'
 #' @author Michael Love, Wolfgang Huber, Simon Anders
 #' 
@@ -113,7 +114,7 @@ NULL
 #' of counts around the expected value for each group, which is critical for
 #' differential expression analysis. If an experimental design is
 #' supplied which does not contain the necessary degrees of freedom for differential
-#' analysis, \code{DESeq} will provide a message to the user and follow
+#' analysis, \code{DESeq} will provide a warning to the user and follow
 #' the strategy outlined in Anders and Huber (2010)
 #' under the section 'Working without replicates', wherein all the samples
 #' are considered as replicates of a single group for the estimation of dispersion.
@@ -121,6 +122,8 @@ NULL
 #' may be expected, which will make that approach conservative."
 #' Furthermore, "while one may not want to draw strong conclusions from such an analysis,
 #' it may still be useful for exploration and hypothesis generation."
+#' We provide this approach for data exploration only, but for accurately
+#' identifying differential expression, biological replicates are required.
 #'
 #' The argument \code{minReplicatesForReplace} is used to decide which samples
 #' are eligible for automatic replacement in the case of extreme Cook's distance.
@@ -203,7 +206,8 @@ NULL
 #' 
 #' @references
 #'
-#' Michael I Love, Wolfgang Huber, Simon Anders: Moderated estimation of fold change and dispersion for RNA-seq data with DESeq2. Genome Biology 2014, 15:550. \url{http://dx.doi.org/10.1186/s13059-014-0550-8}
+#' Love, M.I., Huber, W., Anders, S. (2014) Moderated estimation of fold change and dispersion for RNA-seq data with DESeq2. Genome Biology, 15:550. \url{https://doi.org/10.1186/s13059-014-0550-8}
+#' 
 #' @import BiocGenerics BiocParallel S4Vectors IRanges GenomicRanges SummarizedExperiment Biobase Rcpp methods
 #'
 #' @importFrom locfit locfit
@@ -537,6 +541,7 @@ estimateSizeFactorsForMatrix <- function(counts, locfunc=stats::median,
 #' default is NULL, in which case a lienar model is used if the
 #' number of groups defined by the model matrix is equal to the number
 #' of columns of the model matrix
+#' @param minmu lower bound on the estimated count for fitting gene-wise dispersion
 #' 
 #' @return a DESeqDataSet with gene-wise, fitted, or final MAP
 #' dispersion estimates in the metadata columns of the object.
@@ -568,7 +573,8 @@ estimateSizeFactorsForMatrix <- function(counts, locfunc=stats::median,
 #' @export
 estimateDispersionsGeneEst <- function(object, minDisp=1e-8, kappa_0=1,
                                        dispTol=1e-6, maxit=100, quiet=FALSE,
-                                       modelMatrix=NULL, niter=1, linearMu=NULL) {
+                                       modelMatrix=NULL, niter=1, linearMu=NULL,
+                                       minmu=0.5) {
   if (!is.null(mcols(object)$dispGeneEst)) {
     if (!quiet) message("found already estimated gene-wise dispersions, removing these")
     removeCols <- c("dispGeneEst")
@@ -628,6 +634,8 @@ estimateDispersionsGeneEst <- function(object, minDisp=1e-8, kappa_0=1,
   # (we need this already to decide about linear mu fitting)
   wlist <- getAndCheckWeights(object, modelMatrix)
   weights <- wlist$weights
+  # don't let weights go below 1e-6
+  weights <- pmax(weights, 1e-6)
   useWeights <- wlist$useWeights
   
   # use a linear model to estimate the expected counts
@@ -646,10 +654,9 @@ estimateDispersionsGeneEst <- function(object, minDisp=1e-8, kappa_0=1,
   fitidx <- rep(TRUE,nrow(objectNZ))
   mu <- matrix(0, nrow=nrow(objectNZ), ncol=ncol(objectNZ))
   dispIter <- numeric(nrow(objectNZ))
-  # bound the estimated count
+  # bound the estimated count by 'minmu'
   # this helps make the fitting more robust,
   # because 1/mu occurs in the weights for the NB GLM
-  minmu <- 0.5
   for (iter in seq_len(niter)) {
     if (!linearMu) {
       fit <- fitNbinomGLMs(objectNZ[fitidx,,drop=FALSE],
@@ -1241,7 +1248,11 @@ nbinomWaldTest <- function(object,
   # if useT is set to TRUE, use a t-distribution
   if (useT) {
     dispPriorVar <- attr( dispersionFunction(object), "dispPriorVar" )
-    stopifnot(length(df)==1)
+    stopifnot(length(df)==1 | length(df)==nrow(object))
+    if (length(df) == nrow(object)) {
+      df <- df[!mcols(object)$allZero]
+      stopifnot(length(df)==nrow(WaldStatistic))
+    }
     WaldPvalue <- 2*pt(abs(WaldStatistic),df=df,lower.tail=FALSE)
   } else {
     WaldPvalue <- 2*pnorm(abs(WaldStatistic),lower.tail=FALSE)
