@@ -1,77 +1,3 @@
-#' Shrink log2 fold changes
-#'
-#' This function adds shrunken log2 fold changes (LFC) to a
-#' results table which was run without LFC moderation.
-#' Note: this function is still being prototyped.
-#'
-#' @param dds a DESeqDataSet object, which has been run through
-#' \code{\link{DESeq}}, or at the least, \code{\link{estimateDispersions}}
-#' @param coef the number of the coefficient (LFC) to shrink,
-#' consult \code{resultsNames(dds)} after running \code{DESeq(dds, betaPrior=FALSE)}.
-#' only \code{coef} or \code{contrast} can be specified, not both
-#' @param contrast see argument description in \code{\link{results}}.
-#' only \code{coef} or \code{contrast} can be specified, not both
-#' @param res a DESeqResults object (can be missing)
-#' @param type at this time, ignored argument, because only one
-#' shrinkage estimator, but more to come!
-#'
-#' @return if \code{res} is not missing, a DESeqResults object with
-#' the \code{log2FoldChange} column replaced with a shrunken LFC.
-#' If \code{res} is missing, just the shrunken LFC vector.
-#'
-#' @export
-#' 
-#' @examples
-#'
-#'  dds <- makeExampleDESeqDataSet(betaSD=1)
-#'  dds <- DESeq(dds, betaPrior=FALSE)
-#'  res <- results(dds)
-#'  res.shr <- lfcShrink(dds=dds, coef=2, res=res)
-#'  res.shr <- lfcShrink(dds=dds, contrast=c("condition","B","A"), res=res)
-#' 
-lfcShrink <- function(dds, coef, contrast, res, type="normal") {
-  if (is.null(dispersions(dds))) {
-    stop("lfcShrink requires dispersion estimates, first call estimateDispersions()")
-  }
-
-  # match the shrinkage type
-  type <- match.arg(type, choices=c("normal"))
-
-  # fit MLE coefficients... TODO skip this step
-  dds <- estimateMLEForBetaPriorVar(dds)
-
-  stopifnot(missing(coef) | missing(contrast))
-  if (missing(contrast)) {
-    modelMatrixType <- "standard"
-  } else {
-    modelMatrixType <- "expanded"
-  }
-  attr(dds,"modelMatrixType") <- modelMatrixType
-  betaPriorVar <- estimateBetaPriorVar(dds)
-
-  dds.shr <- nbinomWaldTest(dds,
-                            betaPrior=TRUE,
-                            betaPriorVar=betaPriorVar,
-                            modelMatrixType=modelMatrixType,
-                            quiet=TRUE)
-
-  if (missing(contrast)) {
-    rn <- resultsNames(dds.shr)
-    res.shr <- results(dds.shr, name=rn[coef])
-  } else {
-    res.shr <- results(dds.shr, contrast=contrast)
-  }
-  
-  if (!missing(res)) {
-    res <- res[,c("baseMean","log2FoldChange","stat","pvalue","padj")]
-    res$log2FoldChange <- res.shr$log2FoldChange
-    mcols(res)$description[2] <- mcols(res.shr)$description[2]
-    return(res)
-  } else {
-    return(res.shr$log2FoldChange)
-  }
-}
-
 #' Unmix samples using loss in a variance stabilized space
 #'
 #' Unmixes samples in \code{x} according to \code{pure} components,
@@ -410,7 +336,7 @@ normalizeGeneLength <- function(...) {
 #' Normalized counts transformation
 #'
 #' A simple function for creating a \code{\link{DESeqTransform}}
-#' object after applying: f(count + pc).
+#' object after applying: \code{f(count(dds,normalized=TRUE) + pc)}.
 #' 
 #' @param object a DESeqDataSet object
 #' @param f a function to apply to normalized counts
