@@ -8,7 +8,9 @@ knitr::opts_chunk$set(tidy=FALSE, cache=TRUE,
 #                                colData = coldata,
 #                                design= ~ batch + condition)
 #  dds <- DESeq(dds)
-#  res <- results(dds, contrast=c("condition","treated","control"))
+#  res <- results(dds, contrast=c("condition","treat","ctrl"))
+#  resultsNames(dds)
+#  res <- lfcShrink(dds, coef=2)
 
 ## ----txiSetup------------------------------------------------------------
 library("tximport")
@@ -47,12 +49,13 @@ coldata <- read.csv(pasAnno, row.names=1)
 coldata <- coldata[,c("condition","type")]
 
 ## ----showPasilla---------------------------------------------------------
-head(cts)
-head(coldata)
+head(cts,2)
+coldata
 
 ## ----reorderPasila-------------------------------------------------------
-rownames(coldata) <- sub("fb","",rownames(coldata))
+rownames(coldata) <- sub("fb", "", rownames(coldata))
 all(rownames(coldata) %in% colnames(cts))
+all(rownames(coldata) == colnames(cts))
 cts <- cts[, rownames(coldata)]
 all(rownames(coldata) == colnames(cts))
 
@@ -100,13 +103,14 @@ ddsSE <- DESeqDataSet(se, design = ~ cell + dex)
 ddsSE
 
 ## ----prefilter-----------------------------------------------------------
-dds <- dds[ rowSums(counts(dds)) > 1, ]
+keep <- rowSums(counts(dds)) >= 10
+dds <- dds[keep,]
 
 ## ----factorlvl-----------------------------------------------------------
-dds$condition <- factor(dds$condition, levels=c("untreated","treated"))
+dds$condition <- factor(dds$condition, levels = c("untreated","treated"))
 
 ## ----relevel-------------------------------------------------------------
-dds$condition <- relevel(dds$condition, ref="untreated")
+dds$condition <- relevel(dds$condition, ref = "untreated")
 
 ## ----droplevels----------------------------------------------------------
 dds$condition <- droplevels(dds$condition)
@@ -118,7 +122,7 @@ res
 
 ## ----lfcShrink-----------------------------------------------------------
 resultsNames(dds)
-resLFC <- lfcShrink(dds, coef=2, res=res)
+resLFC <- lfcShrink(dds, coef=2)
 resLFC
 
 ## ----parallel, eval=FALSE------------------------------------------------
@@ -126,7 +130,7 @@ resLFC
 #  register(MulticoreParam(4))
 
 ## ----resOrder------------------------------------------------------------
-resOrdered <- res[order(res$padj),]
+resOrdered <- res[order(res$pvalue),]
 
 ## ----sumRes--------------------------------------------------------------
 summary(res)
@@ -156,6 +160,17 @@ plotMA(resLFC, ylim=c(-2,2))
 #  idx <- identify(res$baseMean, res$log2FoldChange)
 #  rownames(res)[idx]
 
+## ----warning=FALSE-------------------------------------------------------
+resApe <- lfcShrink(dds, coef=2, type="apeglm")
+resAsh <- lfcShrink(dds, coef=2, type="ashr")
+
+## ----fig.width=8, fig.height=3-------------------------------------------
+par(mfrow=c(1,3), mar=c(4,4,2,1))
+xlim <- c(1,1e5); ylim <- c(-3,3)
+plotMA(resLFC, xlim=xlim, ylim=ylim, main="normal")
+plotMA(resApe, xlim=xlim, ylim=ylim, main="apeglm")
+plotMA(resAsh, xlim=xlim, ylim=ylim, main="ashr")
+
 ## ----plotCounts----------------------------------------------------------
 plotCounts(dds, gene=which.min(res$padj), intgroup="condition")
 
@@ -184,6 +199,11 @@ colData(dds)
 ## ----copyMultifactor-----------------------------------------------------
 ddsMF <- dds
 
+## ----fixLevels-----------------------------------------------------------
+levels(ddsMF$type)
+levels(ddsMF$type) <- sub("-.*", "", levels(ddsMF$type))
+levels(ddsMF$type)
+
 ## ----replaceDesign-------------------------------------------------------
 design(ddsMF) <- formula(~ type + condition)
 ddsMF <- DESeq(ddsMF)
@@ -194,23 +214,21 @@ head(resMF)
 
 ## ----multiTypeResults----------------------------------------------------
 resMFType <- results(ddsMF,
-                     contrast=c("type", "single-read", "paired-end"))
+                     contrast=c("type", "single", "paired"))
 head(resMFType)
 
 ## ----rlogAndVST----------------------------------------------------------
+vsd <- vst(dds, blind=FALSE)
 rld <- rlog(dds, blind=FALSE)
-vsd <- varianceStabilizingTransformation(dds, blind=FALSE)
-vsd.fast <- vst(dds, blind=FALSE)
-head(assay(rld), 3)
+head(assay(vsd), 3)
 
 ## ----meansd--------------------------------------------------------------
 # this gives log2(n + 1)
 ntd <- normTransform(dds)
 library("vsn")
-notAllZero <- (rowSums(counts(dds))>0)
-meanSdPlot(assay(ntd)[notAllZero,])
-meanSdPlot(assay(rld[notAllZero,]))
-meanSdPlot(assay(vsd[notAllZero,]))
+meanSdPlot(assay(ntd))
+meanSdPlot(assay(vsd))
+meanSdPlot(assay(rld))
 
 ## ----heatmap-------------------------------------------------------------
 library("pheatmap")
@@ -219,18 +237,18 @@ select <- order(rowMeans(counts(dds,normalized=TRUE)),
 df <- as.data.frame(colData(dds)[,c("condition","type")])
 pheatmap(assay(ntd)[select,], cluster_rows=FALSE, show_rownames=FALSE,
          cluster_cols=FALSE, annotation_col=df)
-pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=FALSE,
-         cluster_cols=FALSE, annotation_col=df)
 pheatmap(assay(vsd)[select,], cluster_rows=FALSE, show_rownames=FALSE,
          cluster_cols=FALSE, annotation_col=df)
+pheatmap(assay(rld)[select,], cluster_rows=FALSE, show_rownames=FALSE,
+         cluster_cols=FALSE, annotation_col=df)
 
 ## ----sampleClust---------------------------------------------------------
-sampleDists <- dist(t(assay(rld)))
+sampleDists <- dist(t(assay(vsd)))
 
-## ----figHeatmapSamples---------------------------------------------------
+## ----figHeatmapSamples, fig.height=4, fig.width=6------------------------
 library("RColorBrewer")
 sampleDistMatrix <- as.matrix(sampleDists)
-rownames(sampleDistMatrix) <- paste(rld$condition, rld$type, sep="-")
+rownames(sampleDistMatrix) <- paste(vsd$condition, vsd$type, sep="-")
 colnames(sampleDistMatrix) <- NULL
 colors <- colorRampPalette( rev(brewer.pal(9, "Blues")) )(255)
 pheatmap(sampleDistMatrix,
@@ -239,10 +257,10 @@ pheatmap(sampleDistMatrix,
          col=colors)
 
 ## ----figPCA--------------------------------------------------------------
-plotPCA(rld, intgroup=c("condition", "type"))
+plotPCA(vsd, intgroup=c("condition", "type"))
 
 ## ----figPCA2-------------------------------------------------------------
-pcaData <- plotPCA(rld, intgroup=c("condition", "type"), returnData=TRUE)
+pcaData <- plotPCA(vsd, intgroup=c("condition", "type"), returnData=TRUE)
 percentVar <- round(100 * attr(pcaData, "percentVar"))
 ggplot(pcaData, aes(PC1, PC2, color=condition, shape=type)) +
   geom_point(size=3) +
@@ -265,7 +283,7 @@ ggplot(pcaData, aes(PC1, PC2, color=condition, shape=type)) +
 #  resultsNames(dds)
 #  results(dds, contrast=c("group", "IB", "IA"))
 
-## ----interFig, echo=FALSE, results="hide"--------------------------------
+## ----interFig, echo=FALSE, results="hide", fig.height=3------------------
 npg <- 20
 mu <- 2^c(8,10,9,11,10,12)
 cond <- rep(rep(c("A","B"),each=npg),3)
@@ -273,7 +291,7 @@ geno <- rep(c("I","II","III"),each=2*npg)
 table(cond, geno)
 counts <- rnbinom(6*npg, mu=rep(mu,each=npg), size=1/.01)
 d <- data.frame(log2c=log2(counts+1), cond, geno)
-library(ggplot2)
+library("ggplot2")
 plotit <- function(d, title) {
   ggplot(d, aes(x=cond, y=log2c, group=geno)) + 
     geom_jitter(size=1.5, position = position_jitter(width=.15)) +
@@ -284,7 +302,7 @@ plotit <- function(d, title) {
 plotit(d, "Gene 1") + ylim(7,13)
 lm(log2c ~ cond + geno + geno:cond, data=d)
 
-## ----interFig2, echo=FALSE, results="hide"-------------------------------
+## ----interFig2, echo=FALSE, results="hide", fig.height=3-----------------
 mu[4] <- 2^12
 mu[6] <- 2^8
 counts <- rnbinom(6*npg, mu=rep(mu,each=npg), size=1/.01)
@@ -329,24 +347,18 @@ resNoFilt <- results(dds, independentFiltering=FALSE)
 addmargins(table(filtering=(res$padj < .1),
                  noFiltering=(resNoFilt$padj < .1)))
 
-## ----ddsNoPrior----------------------------------------------------------
-ddsNoPrior <- DESeq(dds, betaPrior=FALSE)
-
 ## ----lfcThresh-----------------------------------------------------------
 par(mfrow=c(2,2),mar=c(2,2,1,1))
-yl <- c(-2.5,2.5)
+ylim <- c(-2.5,2.5)
 resGA <- results(dds, lfcThreshold=.5, altHypothesis="greaterAbs")
-resLA <- results(ddsNoPrior, lfcThreshold=.5, altHypothesis="lessAbs")
+resLA <- results(dds, lfcThreshold=.5, altHypothesis="lessAbs")
 resG <- results(dds, lfcThreshold=.5, altHypothesis="greater")
 resL <- results(dds, lfcThreshold=.5, altHypothesis="less")
-plotMA(resGA, ylim=yl)
-abline(h=c(-.5,.5),col="dodgerblue",lwd=2)
-plotMA(resLA, ylim=yl)
-abline(h=c(-.5,.5),col="dodgerblue",lwd=2)
-plotMA(resG, ylim=yl)
-abline(h=.5,col="dodgerblue",lwd=2)
-plotMA(resL, ylim=yl)
-abline(h=-.5,col="dodgerblue",lwd=2)
+drawLines <- function() abline(h=c(-.5,.5),col="dodgerblue",lwd=2)
+plotMA(resGA, ylim=ylim); drawLines()
+plotMA(resLA, ylim=ylim); drawLines()
+plotMA(resG, ylim=ylim); drawLines()
+plotMA(resL, ylim=ylim); drawLines()
 
 ## ----mcols---------------------------------------------------------------
 mcols(dds,use.names=TRUE)[1:4,1:4]
@@ -370,6 +382,11 @@ head(coef(dds))
 ## ----betaPriorVar--------------------------------------------------------
 attr(dds, "betaPriorVar")
 
+## ----priorInfo-----------------------------------------------------------
+priorInfo(resLFC)
+priorInfo(resApe)
+priorInfo(resAsh)
+
 ## ----dispPriorVar--------------------------------------------------------
 dispersionFunction(dds)
 attr(dispersionFunction(dds), "dispPriorVar")
@@ -478,8 +495,8 @@ dds2 <- makeExampleDESeqDataSet(n=1000,m=12,
 dds2 <- dds2[,7:12]
 dds2$condition <- rep("C",6)
 mcols(dds2) <- NULL
-dds <- cbind(dds1, dds2)
-rld <- rlog(dds, blind=FALSE, fitType="mean")
+dds12 <- cbind(dds1, dds2)
+rld <- rlog(dds12, blind=FALSE, fitType="mean")
 plotPCA(rld)
 
 ## ----convertNA, eval=FALSE-----------------------------------------------
