@@ -41,9 +41,9 @@ test_that("results works as expected and throws errors", {
   # check to see if the contrasts with expanded model matrix
   # are close to expected (although shrunk due to the beta prior).
   # lfcShrink() here calls results()
-  lfc31 <- lfcShrink(dds,contrast=c("condition","3","1"))[1]
-  lfc21 <- lfcShrink(dds,contrast=c("condition","2","1"))[1]
-  lfc32 <- lfcShrink(dds,contrast=c("condition","3","2"))[1]
+  lfc31 <- lfcShrink(dds,contrast=c("condition","3","1"))[1,"log2FoldChange"]
+  lfc21 <- lfcShrink(dds,contrast=c("condition","2","1"))[1,"log2FoldChange"]
+  lfc32 <- lfcShrink(dds,contrast=c("condition","3","2"))[1,"log2FoldChange"]
   expect_equal(lfc31, 3, tolerance=.1)
   expect_equal(lfc21, 1, tolerance=.1)
   expect_equal(lfc32, 2, tolerance=.1)
@@ -55,9 +55,12 @@ test_that("results works as expected and throws errors", {
   dds2 <- dds
   colData(dds2)$condition <- relevel(colData(dds2)$condition, "2")
   dds2 <- DESeq(dds2)
-  expect_equal(lfcShrink(dds2,contrast=c("condition","3","1"))[1], lfc31, tolerance=1e-6)
-  expect_equal(lfcShrink(dds2,contrast=c("condition","2","1"))[1], lfc21, tolerance=1e-6)
-  expect_equal(lfcShrink(dds2,contrast=c("condition","3","2"))[1], lfc32, tolerance=1e-6)
+  expect_equal(lfcShrink(dds2,contrast=c("condition","3","1"))[1,"log2FoldChange"],
+               lfc31, tolerance=1e-6)
+  expect_equal(lfcShrink(dds2,contrast=c("condition","2","1"))[1,"log2FoldChange"],
+               lfc21, tolerance=1e-6)
+  expect_equal(lfcShrink(dds2,contrast=c("condition","3","2"))[1,"log2FoldChange"],
+               lfc32, tolerance=1e-6)
 
   # test a number of contrast as list options
   expect_equal(results(dds, contrast=list("condition_3_vs_1","condition_2_vs_1"))[1,2],
